@@ -9,7 +9,8 @@ import hmac
 import time
 
 from jinja2.exceptions import TemplateNotFound
-from shake import url_for, from36, to36, redirect, Rule, StorageDict
+from shake import (url_for, from36, to36, redirect, Rule, StorageDict,
+    to_bytestring)
 
 try:
     import mailshake
@@ -45,7 +46,7 @@ class UserDoesNotExistsError(ValueError):
         self.login = login
     
     def __repr__(self):
-        return "A user with the login '%s' dosen't exists." % self.login
+        return "User '%s' not found." % self.login
 
 
 class PasswordTooShortError(ValueError):
@@ -59,9 +60,8 @@ class PasswordTooShortError(ValueError):
 
 
 class Auth(object):
-    """
-    # Parameters:
-
+    """The authentication class.
+    
     User
     :   an User model.
         
@@ -264,13 +264,13 @@ class Auth(object):
         login = credentials.get(CREDENTIAL_LOGIN)
         password = credentials.get(CREDENTIAL_PASSWORD)
         if login and password:
-            login = login.encode('utf8', 'ignore')
-            password = password.encode('utf8', 'ignore')
+            login = to_bytestring(login)
+            password = to_bytestring(password)
             return self._loginpass_authentication(login, password, update)
         
         token = credentials.get(CREDENTIAL_TOKEN)
         if token:
-            token = token.encode('utf8', 'ignore')
+            token = to_bytestring(token)
             return self._token_authentication(token)
     
 
@@ -317,6 +317,7 @@ class Auth(object):
 
     def hash_password(self, password):
         password += self.settings.pepper
+        password = to_bytestring(password)
         return self.hash_func(password, cost=self.settings.hash_cost)
     
 
@@ -327,7 +328,9 @@ class Auth(object):
         """
         if stored_password is None:
             return False
-        
+
+        password = to_bytestring(password)
+        stored_password = to_bytestring(stored_password)
         try:
             hash_alg, hash_cost, salt = split_hash(stored_password)
         except ValueError:
